DirectEnumLens<T> class

An enum lens backed by explicitly provided getter and setter functions.

Inheritance
Mixed-in types

Constructors

DirectEnumLens({required Getter<T> get, required Setter<T> set, required List<T> values})
An enum lens backed by explicitly provided getter and setter functions.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
Index of the current value in values.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<T>
The list of allowed values for this lens.
final

Methods

get() → T
Returns the value managed by this lens.
inherited
next() → void
Cycles to the next value in values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(T value) → void
Sets the value managed by this lens.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited